==> opencity_0.0.6.4stable.orig.tar.bz2: opencity-0.0.6.4stable/src/mas/agentposition.h <==
/***************************************************************************
						agentposition.h  -  description
							-------------------
	begin                : may 1st, 2008
	copyright            : (C) 2008 by Duong Khang NGUYEN
	email                : neoneurone @ gmail com

	$Id: agentposition.h 375 2008-10-28 14:47:15Z neoneurone $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   any later version.                                                    *
 *                                                                         *
 ***************************************************************************/


#ifndef _OPENCITY_AGENTPOSITION_H_
#define _OPENCITY_AGENTPOSITION_H_ 1


//========================================================================
/** Utility class used to handle each agent's position
*/
class AgentPosition
{
public:
	int x, y;				///< 2D coordinates of the agent on the map
	unsigned long step;

	AgentPosition() : x(-1), y(-1), step(0) {}
	AgentPosition(int xx, int yy, unsigned long xstep) : x(xx), y(yy), step(xstep) {}
	AgentPosition(const AgentPosition &p) : x(p.x), y(p.y), step(p.step) {}
};

#endif

==> opencity_0.0.6.5stable.orig.tar.bz2: opencity-0.0.6.5stable/src/mas/agentposition.h <==
/***************************************************************************
                      agentposition.h  -  description
							-------------------
	begin                : may 1st, 2008
	copyright            : (C) 2008-2010 by Duong Khang NGUYEN
	email                : neoneurone @ gmail com

	$Id: agentposition.h 448 2010-05-09 15:18:32Z neoneurone $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   any later version.                                                    *
 *                                                                         *
 ***************************************************************************/


#ifndef _OPENCITY_MAS_AGENTPOSITION_H_
#define _OPENCITY_MAS_AGENTPOSITION_H_ 1


//========================================================================
/** Utility class used to handle each agent's position
*/
class AgentPosition
{
public:
	int x, y;				///< 2D coordinates of the agent on the map
	unsigned long step;

	AgentPosition() : x(-1), y(-1), step(0) {}
	AgentPosition(int xx, int yy, unsigned long xstep) : x(xx), y(yy), step(xstep) {}
	AgentPosition(const AgentPosition& p) : x(p.x), y(p.y), step(p.step) {}
};

#endif
